ContactFetcherPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ContactFetcherPlatform
Implementers

Constructors

ContactFetcherPlatform()
Constructs a ContactFetcherPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllContact({int limit = 10, int pageNumber = 0}) Future<List<Contact>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ContactFetcherPlatform
The default instance of ContactFetcherPlatform to use.
getter/setter pair